@@ -70,30 +70,88 @@ def print_run(for_, cores, conda):
     )
 
 
-def check_dm_xv(fdffile, i, label, cwd, cont):
-    """Check DM and XV parameters in an FDF file"""
+def check_restart(fdffile, i, label, cwd, cont, contextensions):
+    """Check DM, XV, CG, and LWF parameters in an FDF file"""
     fdf = fdffile.read()
-    matchdm = re.search(r"#DM\.UseSaveDM +\.true\.", fdf)
-    matchxv = re.search(r"#MD\.UseSaveXV +\.true\.", fdf)
-    if matchdm is None:
-        matchdm = re.search(r"DM\.UseSaveDM +\.false\.", fdf)
-    if matchxv is None:
-        matchxv = re.search(r"MD\.UseSaveXV +\.false\.", fdf)
-    if matchdm is None:
-        fdf += "\nDM.UseSaveDM        .true.\n"
-    else:
-        fdf.replace(matchdm[0], "DM.UseSaveDM        .true.")
-    if matchxv is None:
-        fdf += "\nMD.UseSaveXV        .true.\n"
-    else:
-        fdf.replace(matchxv[0], "MD.UseSaveXV        .true.")
-    print(
-        f"Setting 'DM.UseSaveDM' and 'MD.UseSaveXV' as '.true.' in {cwd}{os.sep}i{i}{os.sep}{cont}{os.sep}{label}.fdf"
-    )
+    if "DM" in contextensions:
+        check_restart_ext(
+            "DM",
+            fdf,
+            r"# *DM\.UseSaveDM +\.true\.",
+            r"DM\.UseSaveDM +\.false\.",
+            "DM.UseSaveDM        .true.",
+            "DM.UseSaveDM",
+            cwd,
+            i,
+            cont,
+            label
+        )
+    if "XV" in contextensions:
+        check_restart_ext(
+            "XV",
+            fdf,
+            r"# *MD\.UseSaveXV +\.true\.",
+            r"MD\.UseSaveXV +\.false\.",
+            "MD.UseSaveXV        .true.",
+            "MD.UseSaveCG",
+            cwd,
+            i,
+            cont,
+            label
+        )
+    if "CG" in contextensions:
+        check_restart_ext(
+            "CG",
+            fdf,
+            r"# *MD\.UseSaveCG +\.true\.",
+            r"MD\.UseSaveCG +\.false\.",
+            "MD.UseSaveCG        .true.",
+            "MD.UseSaveCG",
+            cwd,
+            i,
+            cont,
+            label
+        )
+    if "LWF" in contextensions:
+        check_restart_ext(
+            "LWF",
+            fdf,
+            r"# *ON\.UseSaveLWF +\.true\.",
+            r"ON\.UseSaveLWF +\.false\.",
+            "ON.UseSaveLWF        .true.",
+            "ON.UseSaveLWF",
+            cwd,
+            i,
+            cont,
+            label
+        )
     fdffile.write(fdf)
-    if re.search("WriteDM +.true.", fdf) is None or re.search("#WriteDM +.true.", fdf) is not None \
-            or re.search("WriteDM +.false.", fdf) is not None:
-        print(f"WARNING: 'WriteDM             .true.' not found in {cwd}{os.sep}i{i}{os.sep}{cont}{os.sep}{label}.fdf")
+
+
+def check_restart_ext(ext, fdf, match1, match2, repl, out, cwd, i, cont, label):
+    """Check DM, XV, CG, and LWF parameters in an FDF file individually"""
+    match = re.search(match1, fdf)
+    if match is None:
+        match = re.search(match2, fdf)
+    if match is None:
+        print(f"Setting '{out}' as '.true.' in {cwd}{os.sep}i{i}{os.sep}{cont}{os.sep}{label}.fdf")
+        fdf += f"\n{repl}\n"
+    else:
+        print(f"Setting '{out}' as '.true.' in {cwd}{os.sep}i{i}{os.sep}{cont}{os.sep}{label}.fdf")
+        fdf.replace(match[0], repl)
+    if ext == "DM" and (re.search("WriteDM +.true.", fdf) is None or re.search("# *WriteDM +.true.", fdf) is not None
+                        or re.search("WriteDM +.false.", fdf) is not None):
+        print(
+            f"WARNING: 'WriteDM             .true.' not found in {cwd}{os.sep}i{i}{os.sep}{cont}{os.sep}{label}.fdf"
+        )
+
+
+def check_userbasis(fdffile):
+    with open(fdffile, "r") as f:
+        if re.search(r"Userbasis *\.true\.", f.read()):
+            return True
+        f.close()
+        return False
 
 
 def copy_file(sourcefile, destinationfile):
